@@ -15,7 +15,7 @@ module.exports = {
     enable: true,
     maxAgeSeconds: 60 * 60 * 24 * 365,
     includeSubdomains: true,
-    preload: true
+    preload: false
   },
   csp: {
     enable: true,
@@ -29,6 +29,7 @@ module.exports = {
     allowFraming: true,
     allowPDFEmbed: true
   },
+  rateLimitNewNotes: 20,
   cookiePolicy: 'lax',
   protocolUseSSL: false,
   allowAnonymous: true,
@@ -159,9 +160,11 @@ module.exports = {
     requiredGroups: [],
     attribute: {
       id: undefined,
-      username: undefined,
-      email: undefined
-    }
+      username: 'http://schemas.xmlsoap.org/ws/2005/05/identity/claims/name',
+      email: 'http://schemas.xmlsoap.org/ws/2005/05/identity/claims/emailaddress'
+    },
+    wantAssertionsSigned: true,
+    wantAuthnResponseSigned: true
   },
   email: true,
   allowEmailRegister: true,
