@@ -5,7 +5,7 @@ const path = require('path')
 const LZString = require('lz-string')
 const base64url = require('base64url')
 const md = require('markdown-it')()
-const metaMarked = require('meta-marked')
+const metaMarked = require('@hedgedoc/meta-marked')
 const cheerio = require('cheerio')
 const shortId = require('shortid')
 const Sequelize = require('sequelize')
@@ -18,6 +18,7 @@ const S = require('string')
 // core
 const config = require('../config')
 const logger = require('../logger')
+const utils = require('../utils')
 
 // ot
 const ot = require('../ot')
@@ -191,9 +192,11 @@ module.exports = function (sequelize, DataTypes) {
       parseNoteIdByAlias: function (_callback) {
         // try to parse note id by alias (e.g. doc)
         Note.findOne({
-          where: {
-            alias: noteId
-          }
+          where: utils.isMySQL(sequelize)
+            ? sequelize.where(sequelize.fn('BINARY', sequelize.col('alias')), noteId)
+            : {
+                alias: noteId
+              }
         }).then(function (note) {
           if (note) {
             const filePath = path.join(config.docsPath, path.basename(noteId) + '.md')
@@ -296,9 +299,11 @@ module.exports = function (sequelize, DataTypes) {
         try {
           if (shortId.isValid(noteId)) {
             Note.findOne({
-              where: {
-                shortid: noteId
-              }
+              where: utils.isMySQL(sequelize)
+                ? sequelize.where(sequelize.fn('BINARY', sequelize.col('shortid')), noteId)
+                : {
+                    shortid: noteId
+                  }
             }).then(function (note) {
               if (!note) return _callback(null, null)
               return callback(null, note.id)
