@@ -13,9 +13,9 @@ const errors = require('./errors')
 
 // public
 const response = {
-  showIndex: showIndex,
-  githubActions: githubActions,
-  gitlabActions: gitlabActions
+  showIndex,
+  githubActions,
+  gitlabActions
 }
 
 function showIndex (req, res, next) {
@@ -29,7 +29,7 @@ function showIndex (req, res, next) {
     imprint: fs.existsSync(path.join(config.docsPath, 'imprint.md')),
     privacyStatement: fs.existsSync(path.join(config.docsPath, 'privacy.md')),
     termsOfUse: fs.existsSync(path.join(config.docsPath, 'terms-of-use.md')),
-    deleteToken: deleteToken
+    deleteToken
   }
 
   if (authStatus) {
@@ -72,8 +72,8 @@ function githubActionGist (req, res, note) {
     const data = {
       client_id: config.github.clientID,
       client_secret: config.github.clientSecret,
-      code: code,
-      state: state
+      code,
+      state
     }
     const authUrl = 'https://github.com/login/oauth/access_token'
     fetch(authUrl, {
@@ -100,7 +100,7 @@ function githubActionGist (req, res, note) {
         files: {}
       }
       gist.files[filename] = {
-        content: content
+        content
       }
       const gistUrl = 'https://api.github.com/gists'
       return fetch(gistUrl, {
