@@ -6,7 +6,7 @@ const DropboxStrategy = require('passport-dropbox-oauth2').Strategy
 const config = require('../../../config')
 const { passportGeneralCallback } = require('../utils')
 
-let dropboxAuth = module.exports = Router()
+const dropboxAuth = module.exports = Router()
 
 passport.use(new DropboxStrategy({
   apiVersion: '2',
