@@ -7,7 +7,7 @@ const config = require('../../../config')
 const response = require('../../../response')
 const { passportGeneralCallback } = require('../utils')
 
-let githubAuth = module.exports = Router()
+const githubAuth = module.exports = Router()
 
 passport.use(new GithubStrategy({
   clientID: config.github.clientID,
