@@ -28,12 +28,13 @@ exports.uploadImage = function (imagePath, callback) {
     }
     const params = {
       Bucket: config.s3bucket,
-      Key: path.join('uploads', path.basename(imagePath)),
+      Key: path.join(config.s3folder, path.basename(imagePath)),
       Body: buffer
     }
 
     const mimeType = getImageMimeType(imagePath)
     if (mimeType) { params.ContentType = mimeType }
+    if (config.s3publicFiles) { params.ACL = 'public-read' }
 
     logger.debug(`S3 object parameters: ${JSON.stringify(params)}`)
     s3.putObject(params, function (err, data) {
