@@ -2,8 +2,7 @@ import modeType from './modeType'
 
 const state = {
   syncscroll: true,
-  currentMode: modeType.view,
-  nightMode: false
+  currentMode: modeType.view
 }
 
 export default state
